@@ -50,16 +50,15 @@
 #ifndef ICALTOMAPI_H
 #define ICALTOMAPI_H
 
-#include "platform.h"
 #include <mapidefs.h>
 #include <string>
-#include <vector>
 #include <list>
 
 #include "icalitem.h"
 #include "icalmapi.h"
 
-#define IC2M_NO_RECIPIENTS 0x0001
+#define IC2M_NO_RECIPIENTS	0x0001
+#define IC2M_APPEND_ONLY	0x0002
 
 class ICALMAPI_API ICalToMapi {
 public:
