@@ -50,7 +50,6 @@
 #ifndef MAPITOICAL_H
 #define MAPITOICAL_H
 
-#include "platform.h"
 #include <string>
 #include <mapidefs.h>
 #include "freebusy.h"
@@ -68,7 +67,7 @@ public:
 	MapiToICal() {};
 	virtual ~MapiToICal() {};
 
-	virtual HRESULT AddMessage(LPMESSAGE lpMessage, ULONG ulFlags) = 0;
+	virtual HRESULT AddMessage(LPMESSAGE lpMessage, std::string strSrvTZ, ULONG ulFlags) = 0;
 	virtual HRESULT AddBlocks(FBBlock_1 *lpsFBblk, LONG ulblocks, time_t tStart, time_t tEnd, std::string strOrganiser, std::string strUser, std::string strUID) = 0;
 	virtual HRESULT Finalize(ULONG ulFlags, std::string *strMethod, std::string *strIcal) = 0;
 	virtual HRESULT ResetObject() = 0;
