@@ -73,11 +73,15 @@ typedef struct icalitem {
 	eIcalType eType;
 	time_t tLastModified;
 	SPropValue sBinGuid;
+	TIMEZONE_STRUCT tTZinfo;
+	ULONG ulFbStatus;
 	recurrence *lpRecurrence;
 	std::list<SPropValue> lstMsgProps; /* all objects are allocated more on icalitem pointer */
 	std::list<ULONG> lstDelPropTags; /* properties to delete from message */
 	std::list<icalrecip> lstRecips;	/* list of all recipients */	
 	struct exception {
+		time_t tBaseDate;
+		time_t tStartDate;
 		std::list<SPropValue> lstAttachProps;
 		std::list<SPropValue> lstMsgProps;
 		std::list<icalrecip> lstRecips;
