@@ -50,14 +50,17 @@
 #ifndef __ICAL_RECURRENCE_H
 #define __ICAL_RECURRENCE_H
 
-#include "platform.h"
 #include "recurrence.h"
 #include "vtimezone.h"
 #include "icalitem.h"
-#include <ECIConv.h>
 #include <mapidefs.h>
 #include <libical/ical.h>
 
+
+#include "ECIConv.h"
+/**
+ * Conversion class for recurrence & exceptions (mapi <-> ical)
+ */
 class ICalRecurrence {
 public:
 	ICalRecurrence();
@@ -65,9 +68,10 @@ public:
 	
 	/* ical -> mapi */
 	HRESULT HrParseICalRecurrenceRule(TIMEZONE_STRUCT sTimeZone, icalcomponent *lpicRootEvent, icalcomponent *lpicEvent,
-									  LPSPropTagArray lpNamedProps, icalitem *lpIcalItem, recurrence **lppRecurrence);
-	HRESULT HrMakeMAPIException(icalcomponent *lpEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem, LPSPropTagArray lpNamedProps, ECIConv *lpIConv, icalitem::exception *lpEx);
+									  bool bIsAllday, LPSPropTagArray lpNamedProps, icalitem *lpIcalItem);
+	HRESULT HrMakeMAPIException(icalcomponent *lpEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem, bool blIsAllday, LPSPropTagArray lpNamedProps, ECIConv *lpIConv, icalitem::exception *lpEx);
 	HRESULT HrMakeMAPIRecurrence(recurrence *lpRecurrence, LPSPropTagArray lpNamedProps, LPMESSAGE lpMessage);
+	bool HrValidateOccurrence(icalitem *lpItem, icalitem::exception lpEx);
 
 	/* mapi -> ical */
 	HRESULT HrCreateICalRecurrence(TIMEZONE_STRUCT sTimeZone, bool bIsAllDay, recurrence *lpRecurrence, icalcomponent *lpicEvent);
