@@ -50,7 +50,6 @@
 #ifndef ICALMAPI_VCONVERTER_H
 #define ICALMAPI_VCONVERTER_H
 
-#include "platform.h"
 #include "vtimezone.h"
 #include "icalitem.h"
 #include "RecurrenceState.h"
@@ -78,11 +77,12 @@ protected:
 	IMailUser *m_lpMailUser;
 	bool m_blCensorPrivate;
 	bool m_bNoRecipients;
+	bool m_blIsAllday;
 	ULONG m_ulUserStatus;
 
 	virtual HRESULT HrGetUID(icalcomponent *lpEvent, std::string *strUid);
 	virtual HRESULT HrMakeBinaryUID(std::string strUid, void *base, SPropValue *lpPropValue);
-	virtual HRESULT HrResolveUser(icalitem *lpIcalItem, std::list<icalrecip> *lplstIcalRecip);
+	virtual HRESULT HrResolveUser(void *base, std::list<icalrecip> *lplstIcalRecip);
 	virtual bool bIsUserLoggedIn(std::string strUser);
 
 	/* ical -> mapi helper functions */
@@ -102,6 +102,8 @@ protected:
 	virtual HRESULT HrAddReminder(icalcomponent *lpicEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem);
 	virtual HRESULT HrAddRecurrence(icalcomponent *lpicEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem);
 	virtual HRESULT HrAddException(icalcomponent *lpEventRoot, icalcomponent *lpEvent, icalitem *lpPrevItem);
+	virtual HRESULT HrAddTimeZone(icalproperty *lpicProp, icalitem *lpIcalItem);
+	virtual HRESULT HrRetrieveAlldayStatus(icalcomponent *lpicEvent, bool *blIsAllday);
 
 	/* mapi -> ical helper functions */
 	virtual HRESULT HrMAPI2ICal(LPMESSAGE lpMessage, icalproperty_method *lpicMethod, icaltimezone **lppicTZinfo, std::string *lpstrTZid, icalcomponent **lppEvent) = 0; /* pure */
