@@ -50,30 +50,14 @@
 #ifndef TIMEZONE_TYPE_H
 #define TIMEZONE_TYPE_H
 
-#include "platform.h"
 #include "recurrence.h"
 #include "mapidefs.h"
 #include <string>
 #include <map>
+#include "TimeUtil.h"
 #include <libical/ical.h>
 
 
-/* MAPI TimeZoneStruct named property */
-typedef struct _TIMEZONE_STRUCT {
-	// The bias values (bias, stdbias and dstbias) are the opposite of what you expect.
-	// Thus +1 hour becomes -60, +2 hours becomes -120, -3 becomes +180
-
-	LONG lBias;					/* nl: -1*60, jp: -9*60 */
-	LONG lStdBias;				/* nl: 0, jp: 0 (wintertijd) */
-	LONG lDstBias;				/* nl: -1*60: jp: 0 (zomertijd) */
-
-	WORD wStdYear;
-	SYSTEMTIME stStdDate;		/* 2->3, dus 3 in wHour */
-
-	WORD wDstYear;
-	SYSTEMTIME stDstDate;		/* 3->2, dus 2 in wHour */
-} TIMEZONE_STRUCT;
-
 
 typedef std::map<std::string, TIMEZONE_STRUCT> timezone_map;
 typedef std::map<std::string, TIMEZONE_STRUCT>::iterator timezone_map_iterator;
@@ -84,8 +68,6 @@ time_t ICalTimeTypeToUTC(icalcomponent *lpicRoot, icalproperty *lpicProp);
 /* Function to convert time to local - used for All day events*/
 time_t ICalTimeTypeToLocal(icalcomponent *lpicRoot, icalproperty *lpicProp);
 
-time_t UTCToLocal(time_t utc, TIMEZONE_STRUCT sTimeZone);
-time_t LocalToUTC(time_t local, TIMEZONE_STRUCT sTimeZone);
 
 /* converts icaltimetype to local time_t */
 time_t icaltime_as_timet_with_server_zone(const struct icaltimetype tt);
