@@ -50,12 +50,9 @@
 #ifndef ECMAPIUTILS
 #define ECMAPIUTILS
 
-#include "platform.h"
 #include <string>
 #include "vmime/dateTime.hpp"
 
-using namespace std;
-
 FILETIME		vmimeDatetimeToFiletime(vmime::datetime dt);
 vmime::datetime	FiletimeTovmimeDatetime(FILETIME ft);
 HRESULT			readStream(IStream *lpStream, std::string &strData);
