@@ -64,6 +64,25 @@
 enum BODYLEVEL { BODY_NONE, BODY_PLAIN, BODY_HTML };
 enum ATTACHLEVEL { ATTACH_NONE, ATTACH_INLINE, ATTACH_NORMAL };
 
+typedef struct sMailState {
+	BODYLEVEL bodyLevel;
+	ATTACHLEVEL attachLevel;
+	bool bAttachSignature;
+	ULONG ulMsgInMsg;
+	std::string strHTMLBody;
+
+	sMailState() {
+		this->reset();
+		ulMsgInMsg = 0;
+	};
+	void reset() {
+		bodyLevel = BODY_NONE;
+		attachLevel = ATTACH_NONE;
+		bAttachSignature = false;
+		strHTMLBody.clear();
+	};
+} sMailState;
+
 class VMIMEToMAPI
 {
 public:
@@ -79,10 +98,7 @@ private:
 	delivery_options m_dopt;
 	LPADRBOOK m_lpAdrBook;
 	IABContainer *m_lpDefaultDir;
-	BODYLEVEL bodyLevel;
-	ATTACHLEVEL attachLevel;
-	bool attach_signature;
-	bool m_bIsMsgInMsg;
+	sMailState m_mailState;
 
 	HRESULT fillMAPIMail(vmime::message* VMMessage, IMessage *lpMessage);
 	HRESULT disectBody(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false, bool bAppendBody = false);
