@@ -53,13 +53,13 @@
 /* WARNING */
 /* mapidefs.h may not be included _before_ any vmime include! */
 
-#include <platform.h>
-#include <ECLogger.h>
 #include <mapix.h>
 #include <mapidefs.h>
 #include <vector>
 #include "options.h"
 
+class ECLogger;
+
 /* we do not need this on linux */
 # define INETMAPI_API
 
@@ -93,9 +93,9 @@ public:
 
 	virtual const unsigned int getRecipientErrorCount() const;
 	virtual const unsigned int getRecipientErrorSMTPCode(unsigned int offset) const;
-	virtual const string getRecipientErrorText(unsigned int offset) const;
-	virtual const string getRecipientErrorDisplayName(unsigned int offset) const;
-	virtual const string getRecipientErrorEmailAddress(unsigned int offset) const;
+	virtual const std::string getRecipientErrorText(unsigned int offset) const;
+	virtual const std::string getRecipientErrorDisplayName(unsigned int offset) const;
+	virtual const std::string getRecipientErrorEmailAddress(unsigned int offset) const;
 };
 
 /* c wrapper to create object */
