@@ -180,6 +180,15 @@ typedef struct tagFBBlock_1
 								between m_tmStart and m_tmEnd. */
 } FBBlock_1;
 
+/**
+ * Extends the free/busy block of data. It also stores the basedate of occurrence
+ * for exceptions. For normal occurrences base date is same as start date
+ */
+typedef struct tagOccrInfo
+{
+	FBBlock_1 fbBlock;
+	time_t tBaseDate;
+} OccrInfo;
 
 /** 
  * Identifies a user that may or may not have free/busy data available.
