@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -59,20 +61,24 @@ using namespace std;
 struct configsetting_t {
 	const char *szName;
 	const char *szValue;
-	unsigned int ulFlags;
+	unsigned short ulFlags;
 #define CONFIGSETTING_ALIAS			0x0001
 #define CONFIGSETTING_RELOADABLE	0x0002
 #define CONFIGSETTING_UNUSED		0x0004
+#define CONFIGSETTING_NONEMPTY		0x0008
+	unsigned short ulGroup;
+#define CONFIGGROUP_PROPMAP			0x0001
 };
 
 struct settingkey_t {
 	char s[256];
-	unsigned int ulFlags;
+	unsigned short ulFlags;
+	unsigned short ulGroup;
 };
 
 struct settingcompare
 {
-	bool operator()(settingkey_t a, settingkey_t b) const
+	bool operator()(const settingkey_t &a, const settingkey_t &b) const
 	{
 		return strcmp(a.s, b.s) < 0;
 	}
@@ -92,23 +98,29 @@ typedef struct {
 /*
  * Flags for the InitDefaults & InitConfigFile functions
  */
-#define CONFIG_LOAD_INIT	0x0001
-#define CONFIG_LOAD_FILE	0x0002
-#define CONFIG_LOAD_RELOAD	0x0004
+#define LOADSETTING_INITIALIZING		0x0001	/* ECConfig is initializing, turns on extra debug information */
+#define LOADSETTING_UNKNOWN				0x0002	/* Allow adding new configuration options */
+#define LOADSETTING_OVERWRITE			0x0004	/* Allow overwriting predefined configuration options */
+#define LOADSETTING_OVERWRITE_GROUP		0x0008	/* Same as CONFIG_LOAD_OVERWRITE but only if options are in the same group */
+#define LOADSETTING_OVERWRITE_RELOAD	0x0010	/* Same as CONFIG_LOAD_OVERWRITE but only if option is marked reloadable */
+
+static const char *lpszDEFAULTDIRECTIVES[] = { "include", NULL };
 
 class ECConfig {
 public:
-	ECConfig(const configsetting_t *lpDefaults);
+	ECConfig(const configsetting_t *lpDefaults, const char **lpszDirectives = lpszDEFAULTDIRECTIVES);
 	~ECConfig();
 
 	bool	LoadSettings(const char *szFilename);
 	bool	ReloadSettings();
 
-	void	AddSetting(const char *szName, const char *szValue);
+	void	AddSetting(const char *szName, const char *szValue, const unsigned int ulGroup = 0);
 
 	char*	GetSetting(const char *szName);
 	char*	GetSetting(const char *szName, char *equal, char *other);
 
+	list<configsetting_t> GetSettingGroup(unsigned int ulGroup);
+
 	bool	HasWarnings();
 	list<string>* GetWarnings();
 	bool	HasErrors();
@@ -117,9 +129,11 @@ public:
 private:
 	bool	InitDefaults(unsigned int ulFlags);
 	bool	InitConfigFile(unsigned int ulFlags);
-	bool	ReadConfigFile(const char *szFilename, unsigned int ulFlags);
+	bool	ReadConfigFile(const char *szFilename, unsigned int ulFlags, unsigned int ulGroup = 0);
 
+	bool	HandleDirective(string &strLine, unsigned int ulFlags);
 	bool	HandleInclude(const char *lpszArgs, unsigned int ulFlags);
+	bool	HandlePropMap(const char *lpszArgs, unsigned int ulFlags);
 
 	char*	GetMapEntry(settingmap_t *lpMap, const char *szName);
 	char*	GetAlias(const char *szAlias);
@@ -129,20 +143,22 @@ private:
 
 	void	CleanupMap(settingmap_t *lpMap);
 	bool	CopyConfigSetting(const configsetting_t *lpsSetting, settingkey_t *lpsKey);
+	bool	CopyConfigSetting(const settingkey_t *lpsKey, const char *szValue, configsetting_t *lpsSetting);
 
-	void	SetPathTo(const char *lpszDir);
+	int		SetPathTo(const char *lpszDir);
 	void	RestorePath();
 
 private:
 	const configsetting_t *m_lpDefaults;
 	const char* m_szConfigFile;
+	list<string> m_lDirectives;
 
 	/* m_mapSettings & m_mapAliases are protected by m_settingsLock */
 	pthread_rwlock_t m_settingsRWLock;
 
 	settingmap_t		m_mapSettings;
 	settingmap_t		m_mapAliases;
-	list<string>	warnings;
+	list<string>		warnings;
 	list<string>		errors;
 	set<string>			m_readFiles;
 	list<string>		m_pathStack;
