@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -52,7 +54,6 @@
 #include <mapi.h>
 #include <mapix.h>
 #include <mapicode.h>
-#include "freebusy.h"
 
 #include "ECDefs.h"
 
@@ -87,9 +88,6 @@ std::string RelationalOperatorToString(ULONG relop);
 std::string FuzzyLevelToString(ULONG ulFuzzyLevel);
 std::string PropValueToString(LPSPropValue  lpPropValue);
 
-std::string GetDebugFBBlock(LONG celt, FBBlock_1* pblk);
-std::string GetFbStatus(FBStatus &fbstatus);
-
 std::string ABFlags(ULONG ulFlag);
 std::string EntryListToString(LPENTRYLIST lpMsgList);
 std::string PermissionRulesToString(ULONG cPermissions, LPECPERMISSION lpECPermissions);
