@@ -198,7 +198,7 @@ typedef struct _sECUser {
 	char*			lpszFullEmail;
 	char*			lpszFullName;
 	char*			lpszServername;
-	unsigned int	ulIsNonActive;	// See objectclass_t, "misuse" of existing variable
+	objectclass_t	ulObjClass;
 	unsigned int	ulIsAdmin;		// See userobject_admin_level_t
 	unsigned int	ulIsABHidden;	// Is user hidden from address book
 	unsigned int	ulCapacity;		// Resource capacity
