@@ -53,12 +53,15 @@
 #include <vector>
 #include <string>
 
+#define RECURRENCE_STATE_CALENDAR	0x01
+#define RECURRENCE_STATE_TASKS		0x02
+
 class RecurrenceState {
 public:
     RecurrenceState();
     ~RecurrenceState();
 
-    HRESULT ParseBlob(char *lpData, unsigned int ulLen);
+    HRESULT ParseBlob(char *lpData, unsigned int ulLen, ULONG ulFlags);
     HRESULT GetBlob(char **lpData, unsigned int *lpulLen, void *base = NULL);
 
     class Exception {
