@@ -75,6 +75,7 @@ public:
 	static HRESULT	HrCopyBinary(ULONG ulSize, LPBYTE lpSrc, ULONG *lpulDestSize, LPBYTE *lppDest, LPVOID lpBase = NULL);
 	static HRESULT	HrCopyEntryId(ULONG ulSize, LPENTRYID lpSrc, ULONG *lpulDestSize, LPENTRYID* lppDest, LPVOID lpBase = NULL);
 
+	static int		CompareSBinary(const SBinary &sbin1, const SBinary &sbin2);
 	static HRESULT	CompareProp(LPSPropValue lpProp1, LPSPropValue lpProp2, int* lpCompareResult);
 	static unsigned int PropSize(LPSPropValue lpProp);
 
@@ -102,6 +103,8 @@ public:
 
 	static HRESULT FileLFtoCRLF(FILE *fin, FILE** fout);
 	static void BufferLFtoCRLF(size_t size, const char *input, char *output, size_t *outsize);
+	static void StringCRLFtoLF(std::string strInput, std::string *strOutput);
+	static void StringTabtoSpaces(std::string strInput, std::string *strOutput);
 
 	static bool StrCaseCompare(const std::string &strInput, const char *lpFind, size_t pos = 0);
 
@@ -132,6 +135,10 @@ public:
 	static HRESULT HrGetQuotaStatus(IMsgStore *lpMsgStore, LPECQUOTA lpsQuota, LPECQUOTASTATUS *lppsQuotaStatus);
 
 	static HRESULT HrDeleteResidualProps(LPMESSAGE lpDestMsg, LPMESSAGE lpSourceMsg, LPSPropTagArray lpsValidProps);
+	static HRESULT ValidMapiPropInterface(LPCIID lpInterface);
+	static HRESULT QueryInterfaceMapiPropOrValidFallback(LPUNKNOWN lpInObj, LPCIID lpInterface, LPUNKNOWN *lppOutObj);
+
+	static HRESULT HrFindEntryIDs(ULONG cbEID, LPENTRYID lpEID, ULONG cbEntryIDs, LPSPropValue lpEntryIDs, BOOL *lpbFound, ULONG* lpPos);
 };
 
 #define RTF_TAG_TYPE_TEXT	0x0000
