@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -94,7 +96,9 @@
 #define ZARAFA_E_INVALID_BOOKMARK		MAKE_ZARAFA_E( 39 )
 #define ZARAFA_E_UNABLE_TO_COMPLETE		MAKE_ZARAFA_E( 40 )
 #define ZARAFA_E_UNKNOWN_INSTANCE_ID	MAKE_ZARAFA_E( 41 )
-#define ZARAFA_E_IGNORE_ME              MAKE_ZARAFA_E( 42 )
+#define ZARAFA_E_IGNORE_ME			MAKE_ZARAFA_E( 42 )
+#define ZARAFA_E_BUSY					MAKE_ZARAFA_E( 43 )
+
 
 #define erSuccess	ZARAFA_E_NONE
 
