@@ -71,11 +71,13 @@ DEFINEMAPIPTR(MAPIFolder);
 DEFINEMAPIPTR(MAPIProp);
 DEFINEMAPIPTR(MAPISession);
 DEFINEMAPIPTR(MAPITable);
+DEFINEMAPIPTR(MailUser);
 DEFINEMAPIPTR(Message);
 DEFINEMAPIPTR(MsgServiceAdmin);
 DEFINEMAPIPTR(MsgStore);
 DEFINEMAPIPTR(ProfAdmin);
 DEFINEMAPIPTR(ProfSect);
+DEFINEMAPIPTR(Unknown);
 typedef mapi_object_ptr<IAttach, IID_IAttachment> AttachPtr;	// Nice... MS (not Mark S) is a bit inconsistent here.
 
 
@@ -86,6 +88,7 @@ typedef mapi_memory_ptr<ROWLIST> RowListPtr;
 typedef mapi_memory_ptr<SPropValue> SPropValuePtr;
 typedef mapi_memory_ptr<SPropTagArray> SPropTagArrayPtr;
 typedef mapi_memory_ptr<SSortOrderSet> SSortOrderSetPtr;
+typedef mapi_memory_ptr<SRestriction> SRestrictionPtr;
 
 
 typedef mapi_array_ptr<SPropValue> SPropArrayPtr;
