@@ -178,8 +178,19 @@
 #define dispidOwnerCriticalChange			0x1a	//PT_SYSTIME
 #define dispidOldWhenStartWhole				0x0029	//PT_SYSTIME
 #define dispidIsException					0x000A	//PT_BOOLEAN
+#define dispidStartRecurrenceDate			0x000D	//PT_LONG
 #define dispidStartRecurrenceTime			0x000E	//PT_LONG
+#define dispidEndRecurrenceDate				0x000F	//PT_LONG
 #define dispidEndRecurrenceTime				0x0010	//PT_LONG
+#define dispidDayInterval					0x0011	//PT_I2
+#define dispidWeekInterval					0x0012	//PT_I2
+#define dispidMonthInterval					0x0013	//PT_I2
+#define dispidYearInterval					0x0014	//PT_I2
+#define dispidDayOfWeekMask					0x0015	//PT_LONG
+#define dispidDayOfMonthMask				0x0016	//PT_LONG
+#define dispidMonthOfYearMask				0x0017	//PT_LONG
+#define dispidOldRecurrenceType				0x0018	//PT_I2
+#define dispidDayOfWeekStart				0x0019	//PT_I2
 
 //In PSETID_Zarafa_CalDav
 #define dispidMozLastAck					0x0001	//PT_SYSTIME	X-MOZ-LAST-ACK 
