@@ -65,8 +65,9 @@
 #include <libgen.h>
 #if defined(__OpenBSD__)
 #include <sys/endian.h>
+#include <sys/param.h>
 #ifndef MAX_PATH
-  #define MAX_PATH 1024
+  #define MAX_PATH PATH_MAX
 #endif
 #else
 #include <byteswap.h>
@@ -348,8 +349,10 @@ typedef unsigned short 	WCHAR;
 
 #ifdef UNICODE
   typedef WCHAR		TCHAR;
+  #define _T(x) L##x
 #else
   typedef char		TCHAR;
+  #define _T(x) x
 #endif
 typedef unsigned char	TBYTE;
 
