@@ -50,7 +50,6 @@
 #ifndef _STRINGUTIL_H
 #define _STRINGUTIL_H
 
-#include "platform.h"
 #include <string>
 #include <vector>
 #include <algorithm>
@@ -79,7 +78,7 @@ std::wstring towstring(const std::string &s);
 std::string tostring(const std::wstring &ws);
 
 // Use casting if passing hard coded values.
-std::string stringify(unsigned int x, bool usehex = false);
+std::string stringify(unsigned int x, bool usehex = false, bool _signed = false);
 std::string stringify_int64(long long x, bool usehex = false);
 std::string stringify_float(float x);
 std::string stringify_double(double x, int prec = 18);
@@ -114,8 +113,7 @@ void strMakeUnicode(const char *lpszA, WCHAR **lpszW);
 
 std::string shell_escape(std::string str);
 
-std::vector<std::string> tokenize(const char *input, const char sep);
-std::vector<std::string> tokenize(const std::string &strInput, const std::string &strSep);
+std::vector<std::string> tokenize(const std::string &strInput, const char sep);
 std::string concatenate(std::vector<std::string> &elements, const std::string &delimeters);
 
 std::string trim(const std::string &strInput, const std::string &strTrim = " ");
@@ -128,4 +126,42 @@ std::string StringEscape(const char* input, const char *tokens, const char escap
 
 std::string strUnEscapeHex(std::string strIn);
 
+template<typename T>
+std::vector<T> tokenize(const T &str, const T &delimiters)
+{
+	std::vector<T> tokens;
+    	
+	// skip delimiters at beginning.
+   	typename T::size_type lastPos = str.find_first_not_of(delimiters, 0);
+    	
+	// find first "non-delimiter".
+   	typename T::size_type pos = str.find_first_of(delimiters, lastPos);
+
+   	while (std::string::npos != pos || std::string::npos != lastPos)
+   	{
+       	// found a token, add it to the std::vector.
+       	tokens.push_back(str.substr(lastPos, pos - lastPos));
+		
+       	// skip delimiters.  Note the "not_of"
+       	lastPos = str.find_first_not_of(delimiters, pos);
+		
+       	// find next "non-delimiter"
+       	pos = str.find_first_of(delimiters, lastPos);
+   	}
+
+	return tokens;
+}
+
+template<typename T>
+std::vector<T> tokenize(const T &str, const typename T::value_type *delimiters)
+{
+	return tokenize(str, (T)delimiters);
+}
+
+template<typename T>
+std::vector<std::basic_string<T> > tokenize(const T* str, const T* delimiters)
+{
+	return tokenize(std::basic_string<T>(str), std::basic_string<T>(delimiters));
+}
+
 #endif
